=encoding utf8

=head1 NAME

Cu::Cyrl - Package for language Cu

=cut

package Locale::CLDR::Locales::Cu::Cyrl;

# This file auto generated
#	on Fri 17 Jan 12:03:31 pm GMT

use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use feature 'unicode_strings';

use Moo;

extends('Locale::CLDR::Locales::Cu');

no Moo;

1;
